aboutsummaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authorRichard Kenner <kenner@vlsi1.ultra.nyu.edu>2001-11-28 14:37:58 +0000
committerRichard Kenner <kenner@gcc.gnu.org>2001-11-28 09:37:58 -0500
commit3e87ad4df7a6f0221cc03ec32a23074577a603f4 (patch)
tree1086e2ce8f57217c7a1eace83e9c49f431869255 /gcc
parentc46080ab33c7115b2802c6c2a0802aa52fd07607 (diff)
downloadgcc-3e87ad4df7a6f0221cc03ec32a23074577a603f4.zip
gcc-3e87ad4df7a6f0221cc03ec32a23074577a603f4.tar.gz
gcc-3e87ad4df7a6f0221cc03ec32a23074577a603f4.tar.bz2
* tree.h (TREE_VIA_PROTECTED): Update to show can be in TREE_VEC.
From-SVN: r47419
Diffstat (limited to 'gcc')
-rw-r--r--gcc/ChangeLog2
-rw-r--r--gcc/tree.h6
2 files changed, 5 insertions, 3 deletions
diff --git a/gcc/ChangeLog b/gcc/ChangeLog
index 34bddc3..6b254b7 100644
--- a/gcc/ChangeLog
+++ b/gcc/ChangeLog
@@ -1,5 +1,7 @@
Wed Nov 28 08:21:47 2001 Richard Kenner <kenner@vlsi1.ultra.nyu.edu>
+ * tree.h (TREE_VIA_PROTECTED): Update to show can be in TREE_VEC.
+
* tree.h: Add missing checks on some macros; make formatting more
consistent.
diff --git a/gcc/tree.h b/gcc/tree.h
index 9182c31..2fa0fc6 100644
--- a/gcc/tree.h
+++ b/gcc/tree.h
@@ -198,6 +198,7 @@ struct tree_common
TREE_VIA_PROTECTED in
TREE_LIST
+ TREE_VEC
TREE_PROTECTED in
BLOCK
??? unspecified nodes
@@ -530,12 +531,11 @@ extern void tree_class_check_failed PARAMS ((const tree, int,
/* Ditto, for `private' declarations. */
#define TREE_VIA_PRIVATE(NODE) ((NODE)->common.private_flag)
/* Nonzero for TREE_LIST node means that the path to the
base class is via a `protected' declaration, which preserves
protected fields from the base class as protected.
OVERLOADED. */
-#define TREE_VIA_PROTECTED(NODE) \
- (TREE_LIST_CHECK (NODE)->common.protected_flag)
+#define TREE_VIA_PROTECTED(NODE) ((NODE)->common.protected_flag)
/* In any expression, nonzero means it has side effects or reevaluation
of the whole expression could produce a different value.
@@ -530,12 +531,11 @@ extern void tree_class_check_failed PARAMS ((const tree, int,
/* Ditto, for `private' declarations. */
#define TREE_VIA_PRIVATE(NODE) ((NODE)->common.private_flag)
-/* Nonzero for TREE_LIST node means that the path to the
+/* Nonzero for TREE_LIST or TREE_VEC node means that the path to the
base class is via a `protected' declaration, which preserves
protected fields from the base class as protected.